/* GPLv2 applies
 * SVN revision: $Revision: 861 $
 * (C) 2006-2014 by folkert@vanheusden.com
 */
const char *get_tooltip(void);
void main_help(void);
void configure_firc_help(void);
void edit_box_help(void);
void commandline_help(void);
void scrollback_help(void);
void scrollback_and_select_help(void);
void user_channel_menu_help(void);
